@@ -335,7 +335,7 @@ static void
 send_if_no_pack_cb (GtkWidget *widget, NS_ui *ui)
 {
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (ui->pack_checkbutton))) {
-		if (GTK_WIDGET_IS_SENSITIVE (ui->pack_entry)) {
+		if (gtk_widget_is_sensitive (ui->pack_entry)) {
 			gtk_widget_grab_focus (ui->pack_entry);
 		} else {
 			gtk_widget_grab_focus (ui->pack_checkbutton);
@@ -429,6 +429,7 @@ set_model_for_options_combobox (NS_ui *ui)
         GtkListStore *model;
 	GtkIconTheme *it;
 	GtkCellRenderer *renderer;
+	GtkWidget *widget;
 	GList *aux;
 	NstPlugin *p;
 	char *last_used = NULL;
@@ -484,6 +485,10 @@ set_model_for_options_combobox (NS_ui *ui)
 
 	gtk_combo_box_set_active (GTK_COMBO_BOX (ui->options_combobox), option);
 
+	/* Grab the focus for the most recently used widget */
+	widget = g_list_nth_data (ui->contact_widgets, option);
+	gtk_widget_grab_focus (widget);
+
 	return last_used_support_dirs;
 }
 
@@ -505,6 +510,20 @@ pack_entry_changed_cb (GObject *object, GParamSpec *spec, NS_ui *ui)
 	gtk_widget_set_sensitive (ui->send_button, send_enabled);
 }
 
+static void
+update_button_image (GtkSettings *settings,
+		     GParamSpec *spec,
+		     GtkWidget *widget)
+{
+	gboolean show_images;
+
+	g_object_get (settings, "gtk-button-images", &show_images, NULL);
+	if (show_images == FALSE)
+		gtk_widget_hide (widget);
+	else
+		gtk_widget_show (widget);
+}
+
 static void
 nautilus_sendto_create_ui (void)
 {
@@ -513,6 +532,8 @@ nautilus_sendto_create_ui (void)
 	NS_ui *ui;
 	gboolean one_file = FALSE;
 	gboolean supports_dirs;
+	GtkSettings *settings;
+	GtkWidget *button_image;
 
 	app = gtk_builder_new ();
 	if (!gtk_builder_add_from_file (app, UIDIR "/" "nautilus-sendto.ui", &error))	{
@@ -535,6 +556,12 @@ nautilus_sendto_create_ui (void)
 	ui->status_label = GTK_WIDGET (gtk_builder_get_object (app, "status_label"));
 	ui->status_image = GTK_WIDGET (gtk_builder_get_object (app, "status_image"));
 
+	settings = gtk_settings_get_default ();
+	button_image = GTK_WIDGET (gtk_builder_get_object (app, "image1"));
+	g_signal_connect (G_OBJECT (settings), "notify::gtk-button-images",
+			  G_CALLBACK (update_button_image), button_image);
+	update_button_image (settings, NULL, button_image);
+
  	gtk_combo_box_set_active (GTK_COMBO_BOX(ui->pack_combobox), 
  		gconf_client_get_int(gconf_client, 
  				NAUTILUS_SENDTO_LAST_COMPRESS, NULL));
@@ -638,8 +665,6 @@ nautilus_sendto_plugin_dir_process (const char *plugindir)
 				if (p->info->init(p)) {
 					plugin_list = g_list_append (plugin_list, p);
 				} else {
-					if (!p->info->never_unload)
-						g_module_close (p->module);
 					g_free (p);
 				}
 			}
@@ -774,7 +799,7 @@ int main (int argc, char **argv)
 	textdomain (GETTEXT_PACKAGE);
 
 	g_thread_init (NULL);
-	context = g_option_context_new (_("Nautilus Sendto"));
+	context = g_option_context_new ("nautilus-sendto");
 	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	if (g_option_context_parse (context, &argc, &argv, &error) == FALSE) {
